@@ -10,6 +10,7 @@
 
 #include "squid.h"
 #include "Debug.h"
+#include "fd.h"
 #include "ipc/Kids.h"
 #include "SquidTime.h"
 #include "util.h"
@@ -96,10 +97,15 @@ DebugFile::reset(FILE *newFile, const char *newName)
     // callers must use nullptr instead of the used-as-the-last-resort stderr
     assert(newFile != stderr || !stderr);
 
-    if (file_)
+    if (file_) {
+        fd_close(fileno(file_));
         fclose(file_);
+    }
     file_ = newFile; // may be nil
 
+    if (file_)
+        fd_open(fileno(file_), FD_LOG, Debug::cache_log);
+
     xfree(name);
     name = newName ? xstrdup(newName) : nullptr;
 
