@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2021 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -16,13 +16,17 @@
 #include "ip/Address.h"
 #include "security/forward.h"
 #include "Store.h"
+#include "XactionStep.h"
 
 class ConnStateData;
 class store_client;
+class ClientHttpRequest;
 
 namespace Ssl
 {
 
+using BumpStep = XactionStep;
+
 /**
  * Maintains bump-server-first related information.
  */
@@ -31,7 +35,7 @@ class ServerBump
     CBDATA_CLASS(ServerBump);
 
 public:
-    explicit ServerBump(HttpRequest *fakeRequest, StoreEntry *e = NULL, Ssl::BumpMode mode = Ssl::bumpServerFirst);
+    explicit ServerBump(ClientHttpRequest *http, StoreEntry *e = nullptr, Ssl::BumpMode mode = Ssl::bumpServerFirst);
     ~ServerBump();
     void attachServerSession(const Security::SessionPointer &); ///< Sets the server TLS session object
     const Security::CertErrors *sslErrors() const; ///< SSL [certificate validation] errors
@@ -39,6 +43,12 @@ public:
     /// whether there was a successful connection to (and peeking at) the origin server
     bool connectedOk() const {return entry && entry->isEmpty();}
 
+    /// whether we are currently performing the given processing step
+    bool at(const BumpStep stp) const { return step == stp; }
+
+    /// whether we are currently performing one of the given processing steps
+    bool at(const BumpStep step1, const BumpStep step2) const { return at(step1) || at(step2); }
+
     /// faked, minimal request; required by Client API
     HttpRequest::Pointer request;
     StoreEntry *entry; ///< for receiving Squid-generated error messages
