@@ -7,14 +7,11 @@
  */
 
 #include "squid.h"
-#include "client_db.h"
 
 #define STUB_API "client_db.cc"
 #include "tests/STUB.h"
 
-class ClientInfo;
-
-void clientdbInit(void) STUB
+#include "client_db.h"
 void clientdbUpdate(const Ip::Address &, const LogTags &, AnyP::ProtocolType, size_t) STUB
 int clientdbCutoffDenied(const Ip::Address &) STUB_RETVAL(-1)
 void clientdbDump(StoreEntry *) STUB
@@ -22,8 +19,10 @@ void clientdbFreeMemory(void) STUB
 int clientdbEstablished(const Ip::Address &, int) STUB_RETVAL(-1)
 #if USE_DELAY_POOLS
 void clientdbSetWriteLimiter(ClientInfo * info, const int writeSpeedLimit,const double initialBurst,const double highWatermark) STUB
-ClientInfo *clientdbGetInfo(const Ip::Address &addr) STUB_RETVAL(NULL)
+ClientInfo *clientdbGetInfo(const Ip::Address &addr) STUB_RETVAL(nullptr)
+#endif
+#if SQUID_SNMP
+Ip::Address *client_entry(Ip::Address *) STUB_RETVAL(nullptr)
+variable_list *snmp_meshCtblFn(variable_list *, snint *) STUB_RETVAL(nullptr)
 #endif
-void clientOpenListenSockets(void) STUB
-void clientHttpConnectionsClose(void) STUB
 
